@@ -1,6 +1,7 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
 use super::analysis;
+use super::client::Client;
 use super::documents;
 use super::documents::Documents;
 use super::language_server;
@@ -8,6 +9,7 @@ use super::tsc;
 
 use crate::diagnostics;
 
+use deno_ast::MediaType;
 use deno_core::anyhow::anyhow;
 use deno_core::error::AnyError;
 use deno_core::resolve_url;
@@ -125,7 +127,7 @@ impl DiagnosticsServer {
   pub(crate) fn start(
     &mut self,
     language_server: Arc<Mutex<language_server::Inner>>,
-    client: lspower::Client,
+    client: Client,
     ts_server: Arc<tsc::TsServer>,
   ) {
     let (tx, mut rx) = mpsc::unbounded_channel::<()>();
@@ -197,15 +199,15 @@ impl DiagnosticsServer {
 impl<'a> From<&'a diagnostics::DiagnosticCategory> for lsp::DiagnosticSeverity {
   fn from(category: &'a diagnostics::DiagnosticCategory) -> Self {
     match category {
-      diagnostics::DiagnosticCategory::Error => lsp::DiagnosticSeverity::Error,
+      diagnostics::DiagnosticCategory::Error => lsp::DiagnosticSeverity::ERROR,
       diagnostics::DiagnosticCategory::Warning => {
-        lsp::DiagnosticSeverity::Warning
+        lsp::DiagnosticSeverity::WARNING
       }
       diagnostics::DiagnosticCategory::Suggestion => {
-        lsp::DiagnosticSeverity::Hint
+        lsp::DiagnosticSeverity::HINT
       }
       diagnostics::DiagnosticCategory::Message => {
-        lsp::DiagnosticSeverity::Information
+        lsp::DiagnosticSeverity::INFORMATION
       }
     }
   }
@@ -286,9 +288,9 @@ fn ts_json_to_diagnostics(
           tags: match d.code {
             // These are codes that indicate the variable is unused.
             2695 | 6133 | 6138 | 6192 | 6196 | 6198 | 6199 | 6205 | 7027
-            | 7028 => Some(vec![lsp::DiagnosticTag::Unnecessary]),
+            | 7028 => Some(vec![lsp::DiagnosticTag::UNNECESSARY]),
             // These are codes that indicated the variable is deprecated.
-            2789 | 6385 | 6387 => Some(vec![lsp::DiagnosticTag::Deprecated]),
+            2789 | 6385 | 6387 => Some(vec![lsp::DiagnosticTag::DEPRECATED]),
             _ => None,
           },
           data: None,
@@ -438,6 +440,8 @@ fn diagnose_dependency(
   diagnostics: &mut Vec<lsp::Diagnostic>,
   documents: &Documents,
   resolved: &deno_graph::Resolved,
+  is_dynamic: bool,
+  maybe_assert_type: Option<&str>,
 ) {
   match resolved {
     Some(Ok((specifier, range))) => {
@@ -445,13 +449,41 @@ fn diagnose_dependency(
         if let Some(message) = doc.maybe_warning() {
           diagnostics.push(lsp::Diagnostic {
             range: documents::to_lsp_range(range),
-            severity: Some(lsp::DiagnosticSeverity::Warning),
+            severity: Some(lsp::DiagnosticSeverity::WARNING),
             code: Some(lsp::NumberOrString::String("deno-warn".to_string())),
             source: Some("deno".to_string()),
             message,
             ..Default::default()
           })
         }
+        if doc.media_type() == MediaType::Json {
+          match maybe_assert_type {
+            // The module has the correct assertion type, no diagnostic
+            Some("json") => (),
+            // The dynamic import statement is missing an assertion type, which
+            // we might not be able to statically detect, therefore we will
+            // not provide a potentially incorrect diagnostic.
+            None if is_dynamic => (),
+            // The module has an incorrect assertion type, diagnostic
+            Some(assert_type) => diagnostics.push(lsp::Diagnostic {
+              range: documents::to_lsp_range(range),
+              severity: Some(lsp::DiagnosticSeverity::ERROR),
+              code: Some(lsp::NumberOrString::String("invalid-assert-type".to_string())),
+              source: Some("deno".to_string()),
+              message: format!("The module is a JSON module and expected an assertion type of \"json\". Instead got \"{}\".", assert_type),
+              ..Default::default()
+            }),
+            // The module is missing an assertion type, diagnostic
+            None => diagnostics.push(lsp::Diagnostic {
+              range: documents::to_lsp_range(range),
+              severity: Some(lsp::DiagnosticSeverity::ERROR),
+              code: Some(lsp::NumberOrString::String("no-assert-type".to_string())),
+              source: Some("deno".to_string()),
+              message: "The module is a JSON module and not being imported with an import assertion. Consider adding `assert { type: \"json\" }` to the import statement.".to_string(),
+              ..Default::default()
+            }),
+          }
+        }
       } else {
         let (code, message) = match specifier.scheme() {
           "file" => (Some(lsp::NumberOrString::String("no-local".to_string())), format!("Unable to load a local module: \"{}\".\n  Please check the file path.", specifier)),
@@ -461,7 +493,7 @@ fn diagnose_dependency(
         };
         diagnostics.push(lsp::Diagnostic {
           range: documents::to_lsp_range(range),
-          severity: Some(lsp::DiagnosticSeverity::Error),
+          severity: Some(lsp::DiagnosticSeverity::ERROR),
           code,
           source: Some("deno".to_string()),
           message,
@@ -472,7 +504,7 @@ fn diagnose_dependency(
     }
     Some(Err(err)) => diagnostics.push(lsp::Diagnostic {
       range: documents::to_lsp_range(err.range()),
-      severity: Some(lsp::DiagnosticSeverity::Error),
+      severity: Some(lsp::DiagnosticSeverity::ERROR),
       code: Some(resolution_error_as_code(err)),
       source: Some("deno".to_string()),
       message: err.to_string(),
@@ -507,11 +539,15 @@ async fn generate_deps_diagnostics(
             &mut diagnostics,
             &snapshot.documents,
             &dependency.maybe_code,
+            dependency.is_dynamic,
+            dependency.maybe_assert_type.as_deref(),
           );
           diagnose_dependency(
             &mut diagnostics,
             &snapshot.documents,
             &dependency.maybe_type,
+            dependency.is_dynamic,
+            dependency.maybe_assert_type.as_deref(),
           );
         }
         diagnostics_vec.push((
@@ -530,7 +566,7 @@ async fn generate_deps_diagnostics(
 
 /// Publishes diagnostics to the client.
 async fn publish_diagnostics(
-  client: &lspower::Client,
+  client: &Client,
   collection: &mut DiagnosticCollection,
   snapshot: &language_server::StateSnapshot,
 ) {
@@ -569,7 +605,7 @@ async fn publish_diagnostics(
 /// Updates diagnostics for any specifiers that don't have the correct version
 /// generated and publishes the diagnostics to the client.
 async fn update_diagnostics(
-  client: &lspower::Client,
+  client: &Client,
   collection: Arc<Mutex<DiagnosticCollection>>,
   snapshot: Arc<language_server::StateSnapshot>,
   ts_server: &tsc::TsServer,
