@@ -46,6 +46,12 @@ itest!(compat_dyn_import_rejects_with_node_compatible_error {
   envs: vec![("DENO_NODE_COMPAT_URL".to_string(), std_file_url())],
 });
 
+itest!(import_esm_from_cjs {
+  args:
+    "run --compat --unstable -A --quiet compat/import_esm_from_cjs/index.js",
+  output_str: Some("function\n"),
+});
+
 #[test]
 fn globals_in_repl() {
   let (out, _err) = util::run_and_collect_output_with_args(
@@ -58,6 +64,20 @@ fn globals_in_repl() {
   assert!(out.contains("true"));
 }
 
+#[test]
+fn require_in_repl() {
+  let (out, _err) = util::run_and_collect_output_with_args(
+    true,
+    vec!["repl", "--compat", "--unstable", "--quiet"],
+    Some(vec![
+      "const foo = require('./compat/import_esm_from_cjs/index');",
+    ]),
+    None,
+    false,
+  );
+  assert!(out.contains("function"));
+}
+
 #[test]
 fn node_compat_url() {
   let (out, err) = util::run_and_collect_output_with_args(
