@@ -63,12 +63,14 @@ fn pty_bad_input() {
 fn pty_syntax_error_input() {
   util::with_pty(&["repl"], |mut console| {
     console.write_line("('\\u')");
-    console.write_line("('");
+    console.write_line("'");
+    console.write_line("[{'a'}];");
     console.write_line("close();");
 
     let output = console.read_all_output();
+    assert!(output.contains("Expected 4 hex characters"));
     assert!(output.contains("Unterminated string constant"));
-    assert!(output.contains("Unexpected eof"));
+    assert!(output.contains("Expected a semicolon"));
   });
 }
 
@@ -120,6 +122,44 @@ fn pty_complete_primitives() {
   });
 }
 
+#[test]
+fn pty_complete_imports() {
+  util::with_pty(&["repl"], |mut console| {
+    // single quotes
+    console.write_line("import './001_hel\t'");
+    // double quotes
+    console.write_line("import { output } from \"./045_out\t\"");
+    console.write_line("output('testing output');");
+    console.write_line("close();");
+
+    let output = console.read_all_output();
+    assert!(output.contains("Hello World"));
+    assert!(output.contains("\ntesting output"));
+  });
+
+  // ensure when the directory changes that the suggestions come from the cwd
+  util::with_pty(&["repl"], |mut console| {
+    console.write_line("Deno.chdir('./subdir');");
+    console.write_line("import '../001_hel\t'");
+    console.write_line("close();");
+
+    let output = console.read_all_output();
+    assert!(output.contains("Hello World"));
+  });
+
+  // ensure nothing too bad happens when deleting the cwd
+  util::with_pty(&["repl"], |mut console| {
+    console.write_line("Deno.mkdirSync('./temp-repl-lsp-dir');");
+    console.write_line("Deno.chdir('./temp-repl-lsp-dir');");
+    console.write_line("Deno.removeSync('../temp-repl-lsp-dir');");
+    console.write_line("import '../001_hello\t'");
+    console.write_line("close();");
+
+    let output = console.read_all_output();
+    assert!(output.contains("Hello World"));
+  });
+}
+
 #[test]
 fn pty_ignore_symbols() {
   util::with_pty(&["repl"], |mut console| {
@@ -267,7 +307,11 @@ fn typescript_declarations() {
     Some(vec![("NO_COLOR".to_owned(), "1".to_owned())]),
     false,
   );
-  assert!(out.ends_with("undefined\n0\n2\nundefined\nundefined\n"));
+  let expected_end_text = "undefined\n0\n2\nundefined\nundefined\n";
+  assert_eq!(
+    &out[out.len() - expected_end_text.len()..],
+    expected_end_text
+  );
   assert!(err.is_empty());
 }
 
