@@ -13,7 +13,6 @@ import {
   assertEquals,
   assertStringIncludes,
   assertThrows,
-  unitTest,
 } from "./test_util.ts";
 import { stripColor } from "../../../test_util/std/fmt/colors.ts";
 
@@ -64,7 +63,7 @@ function cssToAnsiEsc(css: Css, prevCss: Css | null = null): string {
 
 // test cases from web-platform-tests
 // via https://github.com/web-platform-tests/wpt/blob/master/console/console-is-a-namespace.any.js
-unitTest(function consoleShouldBeANamespace() {
+Deno.test(function consoleShouldBeANamespace() {
   const prototype1 = Object.getPrototypeOf(console);
   const prototype2 = Object.getPrototypeOf(prototype1);
 
@@ -72,12 +71,12 @@ unitTest(function consoleShouldBeANamespace() {
   assertEquals(prototype2, Object.prototype);
 });
 
-unitTest(function consoleHasRightInstance() {
+Deno.test(function consoleHasRightInstance() {
   assert(console instanceof Console);
   assertEquals({} instanceof Console, false);
 });
 
-unitTest(function consoleTestAssertShouldNotThrowError() {
+Deno.test(function consoleTestAssertShouldNotThrowError() {
   mockConsole((console) => {
     console.assert(true);
     let hasThrown = undefined;
@@ -91,13 +90,13 @@ unitTest(function consoleTestAssertShouldNotThrowError() {
   });
 });
 
-unitTest(function consoleTestStringifyComplexObjects() {
+Deno.test(function consoleTestStringifyComplexObjects() {
   assertEquals(stringify("foo"), "foo");
   assertEquals(stringify(["foo", "bar"]), `[ "foo", "bar" ]`);
   assertEquals(stringify({ foo: "bar" }), `{ foo: "bar" }`);
 });
 
-unitTest(
+Deno.test(
   function consoleTestStringifyComplexObjectsWithEscapedSequences() {
     assertEquals(
       stringify(
@@ -167,14 +166,14 @@ unitTest(
   },
 );
 
-unitTest(function consoleTestStringifyQuotes() {
+Deno.test(function consoleTestStringifyQuotes() {
   assertEquals(stringify(["\\"]), `[ "\\\\" ]`);
   assertEquals(stringify(['\\,"']), `[ '\\\\,"' ]`);
   assertEquals(stringify([`\\,",'`]), `[ \`\\\\,",'\` ]`);
   assertEquals(stringify(["\\,\",',`"]), `[ "\\\\,\\",',\`" ]`);
 });
 
-unitTest(function consoleTestStringifyLongStrings() {
+Deno.test(function consoleTestStringifyLongStrings() {
   const veryLongString = "a".repeat(200);
   // If we stringify an object containing the long string, it gets abbreviated.
   let actual = stringify({ veryLongString });
@@ -185,7 +184,7 @@ unitTest(function consoleTestStringifyLongStrings() {
   assertEquals(actual, veryLongString);
 });
 
-unitTest(function consoleTestStringifyCircular() {
+Deno.test(function consoleTestStringifyCircular() {
   class Base {
     a = 1;
     m1() {}
@@ -357,7 +356,7 @@ unitTest(function consoleTestStringifyCircular() {
   assertEquals(stripColor(Deno.inspect(nestedObj)), nestedObjExpected);
 });
 
-unitTest(function consoleTestStringifyFunctionWithPrototypeRemoved() {
+Deno.test(function consoleTestStringifyFunctionWithPrototypeRemoved() {
   const f = function f() {};
   Reflect.setPrototypeOf(f, null);
   assertEquals(stringify(f), "[Function: f]");
@@ -372,7 +371,7 @@ unitTest(function consoleTestStringifyFunctionWithPrototypeRemoved() {
   assertEquals(stringify(agf), "[Function: agf]");
 });
 
-unitTest(function consoleTestStringifyFunctionWithProperties() {
+Deno.test(function consoleTestStringifyFunctionWithProperties() {
   const f = () => "test";
   f.x = () => "foo";
   f.y = 3;
@@ -416,7 +415,7 @@ unitTest(function consoleTestStringifyFunctionWithProperties() {
   );
 });
 
-unitTest(function consoleTestStringifyWithDepth() {
+Deno.test(function consoleTestStringifyWithDepth() {
   // deno-lint-ignore no-explicit-any
   const nestedObj: any = { a: { b: { c: { d: { e: { f: 42 } } } } } };
   assertEquals(
@@ -439,7 +438,7 @@ unitTest(function consoleTestStringifyWithDepth() {
   );
 });
 
-unitTest(function consoleTestStringifyLargeObject() {
+Deno.test(function consoleTestStringifyLargeObject() {
   const obj = {
     a: 2,
     o: {
@@ -475,7 +474,7 @@ unitTest(function consoleTestStringifyLargeObject() {
   );
 });
 
-unitTest(function consoleTestStringifyIterable() {
+Deno.test(function consoleTestStringifyIterable() {
   const shortArray = [1, 2, 3, 4, 5];
   assertEquals(stringify(shortArray), "[ 1, 2, 3, 4, 5 ]");
 
@@ -771,7 +770,7 @@ unitTest(function consoleTestStringifyIterable() {
   */
 });
 
-unitTest(function consoleTestStringifyIterableWhenGrouped() {
+Deno.test(function consoleTestStringifyIterableWhenGrouped() {
   const withOddNumberOfEls = new Float64Array(
     [
       2.1,
@@ -849,7 +848,7 @@ unitTest(function consoleTestStringifyIterableWhenGrouped() {
   );
 });
 
-unitTest(async function consoleTestStringifyPromises() {
+Deno.test(async function consoleTestStringifyPromises() {
   const pendingPromise = new Promise((_res, _rej) => {});
   assertEquals(stringify(pendingPromise), "Promise { <pending> }");
 
@@ -872,7 +871,7 @@ unitTest(async function consoleTestStringifyPromises() {
   assertEquals(strLines[1], "  <rejected> Error: Whoops");
 });
 
-unitTest(function consoleTestWithCustomInspector() {
+Deno.test(function consoleTestWithCustomInspector() {
   class A {
     [customInspect](): string {
       return "b";
@@ -882,7 +881,7 @@ unitTest(function consoleTestWithCustomInspector() {
   assertEquals(stringify(new A()), "b");
 });
 
-unitTest(function consoleTestWithCustomInspectorUsingInspectFunc() {
+Deno.test(function consoleTestWithCustomInspectorUsingInspectFunc() {
   class A {
     [customInspect](
       inspect: (v: unknown, opts?: Deno.InspectOptions) => string,
@@ -894,7 +893,7 @@ unitTest(function consoleTestWithCustomInspectorUsingInspectFunc() {
   assertEquals(stringify(new A()), "b { c: 1 }");
 });
 
-unitTest(function consoleTestWithCustomInspectorError() {
+Deno.test(function consoleTestWithCustomInspectorError() {
   class A {
     [customInspect](): never {
       throw new Error("BOOM");
@@ -916,7 +915,7 @@ unitTest(function consoleTestWithCustomInspectorError() {
   );
 });
 
-unitTest(function consoleTestWithCustomInspectFunction() {
+Deno.test(function consoleTestWithCustomInspectFunction() {
   function a() {}
   Object.assign(a, {
     [customInspect]() {
@@ -927,7 +926,7 @@ unitTest(function consoleTestWithCustomInspectFunction() {
   assertEquals(stringify(a), "b");
 });
 
-unitTest(function consoleTestWithIntegerFormatSpecifier() {
+Deno.test(function consoleTestWithIntegerFormatSpecifier() {
   assertEquals(stringify("%i"), "%i");
   assertEquals(stringify("%i", 42.0), "42");
   assertEquals(stringify("%i", 42), "42");
@@ -945,7 +944,7 @@ unitTest(function consoleTestWithIntegerFormatSpecifier() {
   );
 });
 
-unitTest(function consoleTestWithFloatFormatSpecifier() {
+Deno.test(function consoleTestWithFloatFormatSpecifier() {
   assertEquals(stringify("%f"), "%f");
   assertEquals(stringify("%f", 42.0), "42");
   assertEquals(stringify("%f", 42), "42");
@@ -960,7 +959,7 @@ unitTest(function consoleTestWithFloatFormatSpecifier() {
   assertEquals(stringify("%f %f", 42), "42 %f");
 });
 
-unitTest(function consoleTestWithStringFormatSpecifier() {
+Deno.test(function consoleTestWithStringFormatSpecifier() {
   assertEquals(stringify("%s"), "%s");
   assertEquals(stringify("%s", undefined), "undefined");
   assertEquals(stringify("%s", "foo"), "foo");
@@ -971,7 +970,7 @@ unitTest(function consoleTestWithStringFormatSpecifier() {
   assertEquals(stringify("%s", Symbol("foo")), "Symbol(foo)");
 });
 
-unitTest(function consoleTestWithObjectFormatSpecifier() {
+Deno.test(function consoleTestWithObjectFormatSpecifier() {
   assertEquals(stringify("%o"), "%o");
   assertEquals(stringify("%o", 42), "42");
   assertEquals(stringify("%o", "foo"), `"foo"`);
@@ -983,13 +982,13 @@ unitTest(function consoleTestWithObjectFormatSpecifier() {
   );
 });
 
-unitTest(function consoleTestWithStyleSpecifier() {
+Deno.test(function consoleTestWithStyleSpecifier() {
   assertEquals(stringify("%cfoo%cbar"), "%cfoo%cbar");
   assertEquals(stringify("%cfoo%cbar", ""), "foo%cbar");
   assertEquals(stripColor(stringify("%cfoo%cbar", "", "color: red")), "foobar");
 });
 
-unitTest(function consoleParseCssColor() {
+Deno.test(function consoleParseCssColor() {
   assertEquals(parseCssColor("black"), [0, 0, 0]);
   assertEquals(parseCssColor("darkmagenta"), [139, 0, 139]);
   assertEquals(parseCssColor("slateblue"), [106, 90, 205]);
@@ -1008,7 +1007,7 @@ unitTest(function consoleParseCssColor() {
   );
 });
 
-unitTest(function consoleParseCss() {
+Deno.test(function consoleParseCss() {
   assertEquals(
     parseCss("background-color: red"),
     { ...DEFAULT_CSS, backgroundColor: [255, 0, 0] },
@@ -1062,7 +1061,7 @@ unitTest(function consoleParseCss() {
   );
 });
 
-unitTest(function consoleCssToAnsi() {
+Deno.test(function consoleCssToAnsi() {
   assertEquals(
     cssToAnsiEsc({ ...DEFAULT_CSS, backgroundColor: [200, 201, 202] }),
     "_[48;2;200;201;202m",
@@ -1102,7 +1101,7 @@ unitTest(function consoleCssToAnsi() {
   );
 });
 
-unitTest(function consoleTestWithVariousOrInvalidFormatSpecifier() {
+Deno.test(function consoleTestWithVariousOrInvalidFormatSpecifier() {
   assertEquals(stringify("%s:%s"), "%s:%s");
   assertEquals(stringify("%i:%i"), "%i:%i");
   assertEquals(stringify("%d:%d"), "%d:%d");
@@ -1118,7 +1117,7 @@ unitTest(function consoleTestWithVariousOrInvalidFormatSpecifier() {
   assertEquals(stringify("abc%", 1), "abc% 1");
 });
 
-unitTest(function consoleTestCallToStringOnLabel() {
+Deno.test(function consoleTestCallToStringOnLabel() {
   const methods = ["count", "countReset", "time", "timeLog", "timeEnd"];
   mockConsole((console) => {
     for (const method of methods) {
@@ -1133,7 +1132,7 @@ unitTest(function consoleTestCallToStringOnLabel() {
   });
 });
 
-unitTest(function consoleTestError() {
+Deno.test(function consoleTestError() {
   class MyError extends Error {
     constructor(errStr: string) {
       super(errStr);
@@ -1151,7 +1150,7 @@ unitTest(function consoleTestError() {
   }
 });
 
-unitTest(function consoleTestClear() {
+Deno.test(function consoleTestClear() {
   mockConsole((console, out) => {
     console.clear();
     assertEquals(out.toString(), "\x1b[1;1H" + "\x1b[0J");
@@ -1159,7 +1158,7 @@ unitTest(function consoleTestClear() {
 });
 
 // Test bound this issue
-unitTest(function consoleDetachedLog() {
+Deno.test(function consoleDetachedLog() {
   mockConsole((console) => {
     const log = console.log;
     const dir = console.dir;
@@ -1232,7 +1231,7 @@ function mockConsole(f: ConsoleExamineFunc) {
 }
 
 // console.group test
-unitTest(function consoleGroup() {
+Deno.test(function consoleGroup() {
   mockConsole((console, out) => {
     console.group("1");
     console.log("2");
@@ -1257,7 +1256,7 @@ unitTest(function consoleGroup() {
 });
 
 // console.group with console.warn test
-unitTest(function consoleGroupWarn() {
+Deno.test(function consoleGroupWarn() {
   mockConsole((console, _out, _err, both) => {
     assert(both);
     console.warn("1");
@@ -1287,7 +1286,7 @@ unitTest(function consoleGroupWarn() {
 });
 
 // console.table test
-unitTest(function consoleTable() {
+Deno.test(function consoleTable() {
   mockConsole((console, out) => {
     console.table({ a: "test", b: 1 });
     assertEquals(
@@ -1535,7 +1534,7 @@ unitTest(function consoleTable() {
 });
 
 // console.log(Error) test
-unitTest(function consoleLogShouldNotThrowError() {
+Deno.test(function consoleLogShouldNotThrowError() {
   mockConsole((console) => {
     let result = 0;
     try {
@@ -1555,7 +1554,7 @@ unitTest(function consoleLogShouldNotThrowError() {
 });
 
 // console.log(Invalid Date) test
-unitTest(function consoleLogShoultNotThrowErrorWhenInvalidDateIsPassed() {
+Deno.test(function consoleLogShoultNotThrowErrorWhenInvalidDateIsPassed() {
   mockConsole((console, out) => {
     const invalidDate = new Date("test");
     console.log(invalidDate);
@@ -1564,7 +1563,7 @@ unitTest(function consoleLogShoultNotThrowErrorWhenInvalidDateIsPassed() {
 });
 
 // console.dir test
-unitTest(function consoleDir() {
+Deno.test(function consoleDir() {
   mockConsole((console, out) => {
     console.dir("DIR");
     assertEquals(out.toString(), "DIR\n");
@@ -1576,7 +1575,7 @@ unitTest(function consoleDir() {
 });
 
 // console.dir test
-unitTest(function consoleDirXml() {
+Deno.test(function consoleDirXml() {
   mockConsole((console, out) => {
     console.dirxml("DIRXML");
     assertEquals(out.toString(), "DIRXML\n");
@@ -1588,7 +1587,7 @@ unitTest(function consoleDirXml() {
 });
 
 // console.trace test
-unitTest(function consoleTrace() {
+Deno.test(function consoleTrace() {
   mockConsole((console, _out, err) => {
     console.trace("%s", "custom message");
     assert(err);
@@ -1596,7 +1595,7 @@ unitTest(function consoleTrace() {
   });
 });
 
-unitTest(function inspectString() {
+Deno.test(function inspectString() {
   assertEquals(
     stripColor(Deno.inspect("\0")),
     `"\\x00"`,
@@ -1607,7 +1606,7 @@ unitTest(function inspectString() {
   );
 });
 
-unitTest(function inspectGetters() {
+Deno.test(function inspectGetters() {
   assertEquals(
     stripColor(Deno.inspect({
       get foo() {
@@ -1636,12 +1635,12 @@ unitTest(function inspectGetters() {
   );
 });
 
-unitTest(function inspectPrototype() {
+Deno.test(function inspectPrototype() {
   class A {}
   assertEquals(Deno.inspect(A.prototype), "A {}");
 });
 
-unitTest(function inspectSorted() {
+Deno.test(function inspectSorted() {
   assertEquals(
     stripColor(Deno.inspect({ b: 2, a: 1 }, { sorted: true })),
     "{ a: 1, b: 2 }",
@@ -1662,7 +1661,7 @@ unitTest(function inspectSorted() {
   );
 });
 
-unitTest(function inspectTrailingComma() {
+Deno.test(function inspectTrailingComma() {
   assertEquals(
     stripColor(Deno.inspect(
       [
@@ -1717,7 +1716,7 @@ unitTest(function inspectTrailingComma() {
   );
 });
 
-unitTest(function inspectCompact() {
+Deno.test(function inspectCompact() {
   assertEquals(
     stripColor(Deno.inspect({ a: 1, b: 2 }, { compact: false })),
     `{
@@ -1727,7 +1726,7 @@ unitTest(function inspectCompact() {
   );
 });
 
-unitTest(function inspectIterableLimit() {
+Deno.test(function inspectIterableLimit() {
   assertEquals(
     stripColor(Deno.inspect(["a", "b", "c"], { iterableLimit: 2 })),
     `[ "a", "b", ... 1 more items ]`,
@@ -1749,7 +1748,7 @@ unitTest(function inspectIterableLimit() {
   );
 });
 
-unitTest(function inspectProxy() {
+Deno.test(function inspectProxy() {
   assertEquals(
     stripColor(Deno.inspect(
       new Proxy([1, 2, 3], {}),
@@ -1823,7 +1822,7 @@ unitTest(function inspectProxy() {
   );
 });
 
-unitTest(function inspectError() {
+Deno.test(function inspectError() {
   const error1 = new Error("This is an error");
   const error2 = new Error("This is an error", {
     cause: new Error("This is a cause error"),
@@ -1843,7 +1842,7 @@ unitTest(function inspectError() {
   );
 });
 
-unitTest(function inspectErrorCircular() {
+Deno.test(function inspectErrorCircular() {
   const error1 = new Error("This is an error");
   const error2 = new Error("This is an error", {
     cause: new Error("This is a cause error"),
@@ -1865,7 +1864,7 @@ unitTest(function inspectErrorCircular() {
   );
 });
 
-unitTest(function inspectColors() {
+Deno.test(function inspectColors() {
   assertEquals(Deno.inspect(1), "1");
   assertStringIncludes(Deno.inspect(1, { colors: true }), "\x1b[");
 });
