@@ -1,49 +1,49 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import { assertNotEquals, assertStrictEquals, unitTest } from "./test_util.ts";
+import { assertNotEquals, assertStrictEquals } from "./test_util.ts";
 
-unitTest(function getRandomValuesInt8Array() {
+Deno.test(function getRandomValuesInt8Array() {
   const arr = new Int8Array(32);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Int8Array(32));
 });
 
-unitTest(function getRandomValuesUint8Array() {
+Deno.test(function getRandomValuesUint8Array() {
   const arr = new Uint8Array(32);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Uint8Array(32));
 });
 
-unitTest(function getRandomValuesUint8ClampedArray() {
+Deno.test(function getRandomValuesUint8ClampedArray() {
   const arr = new Uint8ClampedArray(32);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Uint8ClampedArray(32));
 });
 
-unitTest(function getRandomValuesInt16Array() {
+Deno.test(function getRandomValuesInt16Array() {
   const arr = new Int16Array(4);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Int16Array(4));
 });
 
-unitTest(function getRandomValuesUint16Array() {
+Deno.test(function getRandomValuesUint16Array() {
   const arr = new Uint16Array(4);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Uint16Array(4));
 });
 
-unitTest(function getRandomValuesInt32Array() {
+Deno.test(function getRandomValuesInt32Array() {
   const arr = new Int32Array(8);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Int32Array(8));
 });
 
-unitTest(function getRandomValuesUint32Array() {
+Deno.test(function getRandomValuesUint32Array() {
   const arr = new Uint32Array(8);
   crypto.getRandomValues(arr);
   assertNotEquals(arr, new Uint32Array(8));
 });
 
-unitTest(function getRandomValuesReturnValue() {
+Deno.test(function getRandomValuesReturnValue() {
   const arr = new Uint32Array(8);
   const rtn = crypto.getRandomValues(arr);
   assertNotEquals(arr, new Uint32Array(8));
