@@ -12,7 +12,6 @@ import {
   deferred,
   delay,
   fail,
-  unitTest,
 } from "./test_util.ts";
 
 async function writeRequestAndReadResponse(conn: Deno.Conn): Promise<string> {
@@ -42,7 +41,7 @@ async function writeRequestAndReadResponse(conn: Deno.Conn): Promise<string> {
   return decoder.decode(dest.bytes());
 }
 
-unitTest({ permissions: { net: true } }, async function httpServerBasic() {
+Deno.test({ permissions: { net: true } }, async function httpServerBasic() {
   const promise = (async () => {
     const listener = Deno.listen({ port: 4501 });
     for await (const conn of listener) {
@@ -68,7 +67,7 @@ unitTest({ permissions: { net: true } }, async function httpServerBasic() {
   await promise;
 });
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerGetRequestBody() {
     const promise = (async () => {
@@ -102,7 +101,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerStreamResponse() {
     const stream = new TransformStream();
@@ -131,7 +130,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerStreamRequest() {
     const stream = new TransformStream();
@@ -170,7 +169,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerStreamDuplex() {
     const promise = (async () => {
@@ -209,7 +208,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { net: true } }, async function httpServerClose() {
+Deno.test({ permissions: { net: true } }, async function httpServerClose() {
   const listener = Deno.listen({ port: 4501 });
   const client = await Deno.connect({ port: 4501 });
   const httpConn = Deno.serveHttp(await listener.accept());
@@ -220,7 +219,7 @@ unitTest({ permissions: { net: true } }, async function httpServerClose() {
   listener.close();
 });
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerInvalidMethod() {
     const listener = Deno.listen({ port: 4501 });
@@ -240,7 +239,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, net: true } },
   async function httpServerWithTls() {
     const hostname = "localhost";
@@ -281,7 +280,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerRegressionHang() {
     const promise = (async () => {
@@ -308,7 +307,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerCancelBodyOnResponseFailure() {
     const promise = (async () => {
@@ -353,7 +352,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerNextRequestErrorExposedInResponse() {
     const promise = (async () => {
@@ -398,7 +397,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerEmptyBlobResponse() {
     const promise = (async () => {
@@ -420,7 +419,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerNextRequestResolvesOnClose() {
     const httpConnList: Deno.HttpConn[] = [];
@@ -452,7 +451,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   // Issue: https://github.com/denoland/deno/issues/10870
   async function httpServerHang() {
@@ -498,7 +497,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   // Issue: https://github.com/denoland/deno/issues/10930
   async function httpServerStreamingResponse() {
@@ -588,7 +587,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpRequestLatin1Headers() {
     const promise = (async () => {
@@ -634,7 +633,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerRequestWithoutPath() {
     const promise = (async () => {
@@ -679,7 +678,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { net: true } }, async function httpServerWebSocket() {
+Deno.test({ permissions: { net: true } }, async function httpServerWebSocket() {
   const promise = (async () => {
     const listener = Deno.listen({ port: 4501 });
     for await (const conn of listener) {
@@ -709,7 +708,7 @@ unitTest({ permissions: { net: true } }, async function httpServerWebSocket() {
   await promise;
 });
 
-unitTest(function httpUpgradeWebSocket() {
+Deno.test(function httpUpgradeWebSocket() {
   const request = new Request("https://deno.land/", {
     headers: {
       connection: "Upgrade",
@@ -727,7 +726,7 @@ unitTest(function httpUpgradeWebSocket() {
   );
 });
 
-unitTest(function httpUpgradeWebSocketMultipleConnectionOptions() {
+Deno.test(function httpUpgradeWebSocketMultipleConnectionOptions() {
   const request = new Request("https://deno.land/", {
     headers: {
       connection: "keep-alive, upgrade",
@@ -739,7 +738,7 @@ unitTest(function httpUpgradeWebSocketMultipleConnectionOptions() {
   assertEquals(response.status, 101);
 });
 
-unitTest(function httpUpgradeWebSocketMultipleUpgradeOptions() {
+Deno.test(function httpUpgradeWebSocketMultipleUpgradeOptions() {
   const request = new Request("https://deno.land/", {
     headers: {
       connection: "upgrade",
@@ -751,7 +750,7 @@ unitTest(function httpUpgradeWebSocketMultipleUpgradeOptions() {
   assertEquals(response.status, 101);
 });
 
-unitTest(function httpUpgradeWebSocketCaseInsensitiveUpgradeHeader() {
+Deno.test(function httpUpgradeWebSocketCaseInsensitiveUpgradeHeader() {
   const request = new Request("https://deno.land/", {
     headers: {
       connection: "upgrade",
@@ -763,7 +762,7 @@ unitTest(function httpUpgradeWebSocketCaseInsensitiveUpgradeHeader() {
   assertEquals(response.status, 101);
 });
 
-unitTest(function httpUpgradeWebSocketInvalidUpgradeHeader() {
+Deno.test(function httpUpgradeWebSocketInvalidUpgradeHeader() {
   assertThrows(
     () => {
       const request = new Request("https://deno.land/", {
@@ -780,7 +779,7 @@ unitTest(function httpUpgradeWebSocketInvalidUpgradeHeader() {
   );
 });
 
-unitTest(function httpUpgradeWebSocketWithoutUpgradeHeader() {
+Deno.test(function httpUpgradeWebSocketWithoutUpgradeHeader() {
   assertThrows(
     () => {
       const request = new Request("https://deno.land/", {
@@ -796,7 +795,7 @@ unitTest(function httpUpgradeWebSocketWithoutUpgradeHeader() {
   );
 });
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpCookieConcatenation() {
     const promise = (async () => {
@@ -827,7 +826,7 @@ unitTest(
 );
 
 // https://github.com/denoland/deno/issues/11651
-unitTest({ permissions: { net: true } }, async function httpServerPanic() {
+Deno.test({ permissions: { net: true } }, async function httpServerPanic() {
   const listener = Deno.listen({ port: 4501 });
   const client = await Deno.connect({ port: 4501 });
   const conn = await listener.accept();
@@ -847,7 +846,7 @@ unitTest({ permissions: { net: true } }, async function httpServerPanic() {
 });
 
 // https://github.com/denoland/deno/issues/11595
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerIncompleteMessage() {
     const listener = Deno.listen({ port: 4501 });
@@ -906,7 +905,7 @@ unitTest(
 );
 
 // https://github.com/denoland/deno/issues/11743
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerDoesntLeakResources() {
     const listener = Deno.listen({ port: 4505 });
@@ -930,7 +929,7 @@ unitTest(
 );
 
 // https://github.com/denoland/deno/issues/11926
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerDoesntLeakResources2() {
     let listener: Deno.Listener;
@@ -972,7 +971,7 @@ unitTest(
 );
 
 // https://github.com/denoland/deno/pull/12216
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function droppedConnSenderNoPanic() {
     async function server() {
@@ -1003,7 +1002,7 @@ unitTest(
 );
 
 // https://github.com/denoland/deno/issues/12193
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpConnConcurrentNextRequestCalls() {
     const hostname = "localhost";
@@ -1040,7 +1039,7 @@ unitTest(
 
 // https://github.com/denoland/deno/pull/12704
 // https://github.com/denoland/deno/pull/12732
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpConnAutoCloseDelayedOnUpgrade() {
     const hostname = "localhost";
@@ -1056,12 +1055,16 @@ unitTest(
 
       const { socket, response } = Deno.upgradeWebSocket(event1.request);
       socket.onmessage = (event) => socket.send(event.data);
+      const socketClosed = new Promise<void>((resolve) => {
+        socket.onclose = () => resolve();
+      });
       event1.respondWith(response);
 
       const event2 = await event2Promise;
       assertStrictEquals(event2, null);
 
       listener.close();
+      await socketClosed;
     }
 
     async function client() {
@@ -1079,7 +1082,7 @@ unitTest(
 // https://github.com/denoland/deno/issues/12741
 // https://github.com/denoland/deno/pull/12746
 // https://github.com/denoland/deno/pull/12798
-unitTest(
+Deno.test(
   { permissions: { net: true, run: true } },
   async function httpServerDeleteRequestHasBody() {
     const hostname = "localhost";
@@ -1110,7 +1113,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function httpServerRespondNonAsciiUint8Array() {
     const promise = (async () => {
