@@ -1,5 +1,5 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import { assertEquals, unitTest } from "./test_util.ts";
+import { assertEquals } from "./test_util.ts";
 import { Buffer } from "../../../test_util/std/io/buffer.ts";
 
 const DEFAULT_BUF_SIZE = 32 * 1024;
@@ -28,7 +28,7 @@ function spyRead(obj: Buffer): Spy {
   return spy;
 }
 
-unitTest(async function copyWithDefaultBufferSize() {
+Deno.test(async function copyWithDefaultBufferSize() {
   const xBytes = repeat("b", DEFAULT_BUF_SIZE);
   const reader = new Buffer(xBytes.buffer as ArrayBuffer);
   const write = new Buffer();
@@ -43,7 +43,7 @@ unitTest(async function copyWithDefaultBufferSize() {
   assertEquals(readSpy.calls, 2); // read with DEFAULT_BUF_SIZE bytes + read with 0 bytes
 });
 
-unitTest(async function copyWithCustomBufferSize() {
+Deno.test(async function copyWithCustomBufferSize() {
   const bufSize = 1024;
   const xBytes = repeat("b", DEFAULT_BUF_SIZE);
   const reader = new Buffer(xBytes.buffer as ArrayBuffer);
@@ -59,7 +59,7 @@ unitTest(async function copyWithCustomBufferSize() {
   assertEquals(readSpy.calls, DEFAULT_BUF_SIZE / bufSize + 1);
 });
 
-unitTest({ permissions: { write: true } }, async function copyBufferToFile() {
+Deno.test({ permissions: { write: true } }, async function copyBufferToFile() {
   const filePath = "test-file.txt";
   // bigger than max File possible buffer 16kb
   const bufSize = 32 * 1024;
