@@ -5,7 +5,6 @@ import {
   assertRejects,
   assertThrows,
   pathToAbsoluteFileUrl,
-  unitTest,
 } from "./test_util.ts";
 
 function assertDirectory(path: string, mode?: number) {
@@ -16,7 +15,7 @@ function assertDirectory(path: string, mode?: number) {
   }
 }
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncSuccess() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -25,7 +24,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncMode() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -34,13 +33,13 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { write: false } }, function mkdirSyncPerm() {
+Deno.test({ permissions: { write: false } }, function mkdirSyncPerm() {
   assertThrows(() => {
     Deno.mkdirSync("/baddir");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirSuccess() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -49,7 +48,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirMode() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -58,7 +57,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { write: true } }, function mkdirErrSyncIfExists() {
+Deno.test({ permissions: { write: true } }, function mkdirErrSyncIfExists() {
   assertThrows(
     () => {
       Deno.mkdirSync(".");
@@ -68,7 +67,7 @@ unitTest({ permissions: { write: true } }, function mkdirErrSyncIfExists() {
   );
 });
 
-unitTest({ permissions: { write: true } }, async function mkdirErrIfExists() {
+Deno.test({ permissions: { write: true } }, async function mkdirErrIfExists() {
   await assertRejects(
     async () => {
       await Deno.mkdir(".");
@@ -78,7 +77,7 @@ unitTest({ permissions: { write: true } }, async function mkdirErrIfExists() {
   );
 });
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncRecursive() {
     const path = Deno.makeTempDirSync() + "/nested/directory";
@@ -87,7 +86,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirRecursive() {
     const path = Deno.makeTempDirSync() + "/nested/directory";
@@ -96,7 +95,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncRecursiveMode() {
     const nested = Deno.makeTempDirSync() + "/nested";
@@ -107,7 +106,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirRecursiveMode() {
     const nested = Deno.makeTempDirSync() + "/nested";
@@ -118,7 +117,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncRecursiveIfExists() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -136,7 +135,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirRecursiveIfExists() {
     const path = Deno.makeTempDirSync() + "/dir";
@@ -154,7 +153,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncErrors() {
     const testDir = Deno.makeTempDirSync();
@@ -205,7 +204,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   function mkdirSyncRelativeUrlPath() {
     const testDir = Deno.makeTempDirSync();
@@ -220,7 +219,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function mkdirRelativeUrlPath() {
     const testDir = Deno.makeTempDirSync();
