@@ -1,13 +1,7 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import {
-  assertEquals,
-  assertThrows,
-  deferred,
-  delay,
-  unitTest,
-} from "./test_util.ts";
+import { assertEquals, assertThrows, deferred, delay } from "./test_util.ts";
 
-unitTest(
+Deno.test(
   { ignore: Deno.build.os !== "windows" },
   function signalsNotImplemented() {
     assertThrows(
@@ -97,7 +91,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { run: true },
@@ -125,7 +119,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { run: true },
@@ -173,7 +167,7 @@ unitTest(
 );
 
 // This tests that pending op_signal_poll doesn't block the runtime from exiting the process.
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { run: true, read: true },
@@ -193,7 +187,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { run: true },
