@@ -1,6 +1,7 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
 use crate::deno_dir::DenoDir;
+use crate::flags::CheckFlag;
 use crate::flags::DenoSubcommand;
 use crate::flags::Flags;
 use crate::flags::RunFlags;
@@ -226,7 +227,7 @@ pub fn compile_to_runtime_flags(
     lock_write: false,
     lock: None,
     log_level: flags.log_level,
-    no_check: false,
+    check: CheckFlag::All,
     compat: flags.compat,
     unsafely_ignore_certificate_errors: flags
       .unsafely_ignore_certificate_errors,
@@ -238,6 +239,6 @@ pub fn compile_to_runtime_flags(
     unstable: flags.unstable,
     v8_flags: flags.v8_flags,
     version: false,
-    watch: false,
+    watch: None,
   })
 }
